@@ -813,15 +813,61 @@ def run_transform_emr(time_spec, service_name, bucketname, prefix_in, xformname,
     print('Error: Unimplemented')
     return None
 
-def run_transform(time_spec, service_name, bucketname, prefix_in, xformname, run_location,**kwargs):
+def run_transform_old(time_spec, service_name, bucketname, prefix_in, xformname, run_location,**kwargs):
+    run_options = dict()
     if (run_location == "inline"):
-        return run_transform_inline(time_spec, service_name, bucketname, prefix_in, xformname,\
-                **kwargs)
+        run_options['run_location'] = 'inline'
+        run_options['time_spec'] = time_spec
+        run_options['service_name'] = service_name
+        run_options['bucketname'] = bucketname
+        run_options['prefix'] = prefix_in
+        run_options['xformname'] = xformname
+        return run_transform_new(**dict(kwargs, run_options=run_options))
     elif (run_location == "singlevm"):
-        instance_type = kwargs.pop('instance_type')
+        run_options['run_location'] = 'singlevm'
+        run_options['time_spec'] = time_spec
+        run_options['service_name'] = service_name
+        run_options['bucketname'] = bucketname
+        run_options['prefix'] = prefix_in
+        run_options['xformname'] = xformname
+        run_options['instance_type'] = kwargs.pop('instance_type')
         return run_transform_singlevm(time_spec, service_name, bucketname, prefix_in, xformname,\
                 instance_type, **kwargs)
     elif (run_location == "emr"):
+        run_options['run_location'] = 'singlevm'
+        run_options['time_spec'] = time_spec
+        run_options['service_name'] = service_name
+        run_options['bucketname'] = bucketname
+        run_options['prefix'] = prefix_in
+        run_options['xformname'] = xformname
+        run_options['instance_type'] = kwargs.pop('instance_type')
+    return run_transform_new(**dict(kwargs, run_options=run_options))
+
+def run_transform(run_options, **kwargs):
+    run_location = run_options.pop('run_location')
+    if (run_location == "inline"):
+        time_spec = run_options.pop('time_spec')
+        service_name = run_options.pop('service_name')
+        bucketname = run_options.pop('bucketname')
+        prefix_in = run_options.pop('prefix')
+        xformname = run_options.pop('xformname')
+        return run_transform_inline(time_spec, service_name, bucketname, prefix_in, xformname,\
+                **kwargs)
+    elif (run_location == "singlevm"):
+        time_spec = run_options.pop('time_spec')
+        service_name = run_options.pop('service_name')
+        bucketname = run_options.pop('bucketname')
+        prefix_in = run_options.pop('prefix')
+        xformname = run_options.pop('xformname')
+        instance_type = run_options.pop('instance_type')
+        return run_transform_singlevm(time_spec, service_name, bucketname, prefix_in, xformname,\
+                instance_type, **kwargs)
+    elif (run_location == "emr"):
+        time_spec = run_options.pop('time_spec')
+        service_name = run_options.pop('service_name')
+        bucketname = run_options.pop('bucketname')
+        prefix_in = run_options.pop('prefix')
+        xformname = run_options.pop('xformname')
         return run_transform_emr(time_spec, service_name, bucketname, prefix_in, xformname,\
                 **kwargs)
 
